==> mythbuntu-common_0.13.orig.tar.gz: mythbuntu-common-0.13/mythbuntu_common/vnc.py <==
# -*- coding: utf-8 -*-
#
# «vnc» - libmythbuntu class for adding/removing VNC from configuration
#
# This script:
# Copyright (C) 2007-2008, Mario Limonciello, for Mythbuntu
#
#
# Mythbuntu is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3 of the License, or at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this application; if not, write to the Free Software Foundation, Inc., 51
# Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os
import sys
import shutil

import xorgconfig

#Script Directory
SCRIPTDIR = '/usr/share/mythbuntu-common/scripts'

class VNCHandler:
    """Used to properly enable VNC in a target configuration"""

    def __init__(self,root=''):
        self.add_modules = ["vnc"]
        self.add_screen = [ ['SecurityTypes', 'VncAuth'], ['UserPasswdVerifier', 'VncAuth'], ['PasswordFile', '/root/.vnc/passwd']]
        self.root = root

        try:
            self.xorg_conf = xorgconfig.readConfig(root + '/etc/X11/xorg.conf')
        except (IOError, xorgconfig.ParseException, AttributeError):
            self.xorg_conf = None

    def create_password(self,password):
        if not os.path.exists("/root/.vnc"):
            os.mkdir("/root/.vnc")
        elif os.path.exists("/root/.vnc/passwd"):
            print "Copying /root/.vnc/passwd to /root/.vnc/passwd.old"
            shutil.copy("/root/.vnc/passwd","/root/.vnc/passwd.old")
        #Create password using expect
        os.system(SCRIPTDIR + "/create_vnc_passwd " + password)
        #let it be readale by anyone doing this
        os.chmod("/root/.vnc/passwd",0664)

    def toggle_xorg(self,enable):
        """Adds necessary lines for enabling VNC upon the next boot"""

        # backup the current xorg.conf
        open(os.path.join(self.root + "/etc/X11/xorg.conf.old"), "w").write(open(self.root + '/etc/X11/xorg.conf').read())

        #Revert any existing settings first
        have_modules = len(self.xorg_conf.getSections("module")) > 0
        screen_opts=self.xorg_conf.getSections("screen")[0].option
        if have_modules:
            for m in self.add_modules:
                self.xorg_conf.getSections("module")[0].removeModule(m)

        for item in self.add_screen:
            if screen_opts.getOptionByName(item[0]) != None:
                screen_opts.removeOptionByName(item[0])

        #Now re-enable if we want to
        if enable:
            if self.add_modules:
                if not have_modules:
                    self.xorg_conf.append(self.xorg_conf.makeSection(None, ["Section","Module"]))
                for m in self.add_modules:
                    self.xorg_conf.getSections("module")[0].addModule(m)

            screen_opts=self.xorg_conf.getSections("screen")[0].option
            for item in self.add_screen:
                screen_opts.append(screen_opts.makeLine(None,item))

        self.xorg_conf.writeConfig(self.root + '/etc/X11/xorg.conf')

==> mythbuntu-common_0.26.orig.tar.gz: mythbuntu-common-0.26/mythbuntu_common/vnc.py <==
# -*- coding: utf-8 -*-
#
# «vnc» - libmythbuntu class for adding/removing VNC from configuration
#
# This script:
# Copyright (C) 2007-2008, Mario Limonciello, for Mythbuntu
#
#
# Mythbuntu is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3 of the License, or at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this application; if not, write to the Free Software Foundation, Inc., 51
# Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os
import sys
import shutil

#import xorgconfig
import XKit
from XKit import xutils

#Script Directory
SCRIPTDIR = '/usr/share/mythbuntu-common/scripts'

class VNCHandler:
    """Used to properly enable VNC in a target configuration"""

    def __init__(self,root=''):
        self.add_modules = ["vnc"]
        self.add_screen = [ ['SecurityTypes', 'VncAuth'], ['UserPasswdVerifier', 'VncAuth'], ['PasswordFile', '/root/.vnc/passwd']]
        self.root = root
        
        self.xorg_conf_path = '/etc/X11/xorg.conf'
        
        try:
            self.xorg_conf = xutils.XUtils(self.xorg_conf_path)
        except(IOError, XKit.xorgparser.ParseException):#if xorg.conf is missing or broken
            self.xorg_conf = xutils.XUtils()

    def create_password(self,password):
        if not os.path.exists("/root/.vnc"):
            os.mkdir("/root/.vnc")
        elif os.path.exists("/root/.vnc/passwd"):
            print "Copying /root/.vnc/passwd to /root/.vnc/passwd.old"
            shutil.copy("/root/.vnc/passwd","/root/.vnc/passwd.old")
        #Create password using expect
        os.system(SCRIPTDIR + "/create_vnc_passwd " + password)
        #let it be readale by anyone doing this
        os.chmod("/root/.vnc/passwd",0664)

    def toggle_xorg(self,enable):
        """Adds necessary lines for enabling VNC upon the next boot"""

        # backup the current xorg.conf
        open(os.path.join(self.root + self.xorg_conf_path + ".old"), "w").write(open(self.root + self.xorg_conf_path).read())
        
        
        #Revert any existing settings first
        have_modules = len(self.xorg_conf.globaldict["Module"]) > 0
        have_screens = len(self.xorg_conf.globaldict["Screen"]) > 0
              
        if have_modules:
            for m in self.add_modules:
                self.xorg_conf.removeOption("Module", "Load", value=m, position=0)
        
        if have_screens:
            for item in self.add_screen:
                self.xorg_conf.removeOption("Screen", item[0], position=0)
        

        #Now re-enable if we want to
        if enable:
            if self.add_modules:
                if not have_modules:
                    self.xorg_conf.makeSection("Module")
                for m in self.add_modules:
                    self.xorg_conf.addOption("Module", "Load", m, position=0)
            
            if not have_screens:
                self.xorg_conf.makeSection("Screen", identifier="Default Screen")
            for item in self.add_screen:
                self.xorg_conf.addOption("Screen", item[0], item[1], optiontype="Option", position=0)
        
        self.xorg_conf.writeFile(self.root + self.xorg_conf_path)
